function [fam] = family(A, n)
%FAMILY Returns parents of a node in a Bayesian network
%  [fam] = FAMILY(A, n) returns the parents of a node in Bayesian network
%     from its incidence matrix
%
%   The input and output parameters are as follows:
%    * A: adjacency matrix of the Bayesian network to use
%    * n: number of the node for which its parents are to be determined
%
%    * fam: parents of the node (sorted according to their node numbers)
%
% --
% The provided software may be used free of charge for research purposes.
% For other uses and further support please contact Franz Pernkopf,
% pernkopf@tugraz.at.
%
% References:
%  F. Pernkopf, M. Wohlmayr, and S. Tschiatschek, 
%  "Maximum Margin Bayesian Network Classifiers," 
%  IEEE Transactions on Pattern Analysis and Machine Intelligence,
%  vol. 99, no. PrePrints, 2011
%
% Authors:
%  F. Pernkopf, M. Wohlmayr, and S. Tschiatschek
%
% Version:
%  1.0 August 24th, 2011
%

fam = sort(find(A(:,n)' ~= 0));

end